@@ -191,10 +191,10 @@ sub complete_caching {
 sub update_cache_map {
 
 		logpkg(__FILE__,__LINE__,'debug', "updating track cache_map");
-		logpkg(__FILE__,__LINE__,'debug',
+		logpkg(__FILE__,__LINE__,'debug', "current track cache entries:",
 			sub {
 				join "\n","cache map", 
-				map{json_out($_)} Audio::Nama::EffectChain::find(track_cache => 1)
+				map{($_->dump)} Audio::Nama::EffectChain::find(track_cache => 1)
 			});
 		my @inserts_list = Audio::Nama::Insert::get_inserts($track->name);
 		my @ops_list = $track->fancy_ops;
